@@ -21,16 +21,16 @@
  */
 
 
-#ifndef __GMIME_FILTER_BASIC_H__
-#define __GMIME_FILTER_BASIC_H__
-
-#include <gmime/gmime-filter.h>
+#ifndef __G_MIME_FILTER_BASIC_H__
+#define __G_MIME_FILTER_BASIC_H__
 
 #ifdef __cplusplus
 extern "C" {
 #pragma }
 #endif /* __cplusplus */
 
+#include <gmime/gmime-filter.h>
+
 #define GMIME_TYPE_FILTER_BASIC            (g_mime_filter_basic_get_type ())
 #define GMIME_FILTER_BASIC(obj)            (GMIME_CHECK_CAST ((obj), GMIME_TYPE_FILTER_BASIC, GMimeFilterBasic))
 #define GMIME_FILTER_BASIC_CLASS(klass)    (GMIME_CHECK_CLASS_CAST ((klass), GMIME_TYPE_FILTER_BASIC, GMimeFilterBasicClass))
@@ -47,7 +47,7 @@ typedef enum {
 	GMIME_FILTER_BASIC_QP_ENC,
 	GMIME_FILTER_BASIC_QP_DEC,
 	GMIME_FILTER_BASIC_UU_ENC,
-	GMIME_FILTER_BASIC_UU_DEC
+	GMIME_FILTER_BASIC_UU_DEC,
 } GMimeFilterBasicType;
 
 struct _GMimeFilterBasic {
