@@ -25,14 +25,8 @@
 #include <config.h>
 #endif
 
-#include "md5-utils.h"
-
 #include "gmime-filter-md5.h"
 
-struct _GMimeFilterMd5Private {
-	MD5Context md5;
-};
-
 static void g_mime_filter_md5_class_init (GMimeFilterMd5Class *klass);
 static void g_mime_filter_md5_init (GMimeFilterMd5 *filter, GMimeFilterMd5Class *klass);
 static void g_mime_filter_md5_finalize (GObject *object);
@@ -92,17 +86,12 @@ g_mime_filter_md5_class_init (GMimeFilterMd5Class *klass)
 static void
 g_mime_filter_md5_init (GMimeFilterMd5 *filter, GMimeFilterMd5Class *klass)
 {
-	filter->priv = g_new (struct _GMimeFilterMd5Private, 1);
-	md5_init (&filter->priv->md5);
+	md5_init (&filter->md5);
 }
 
 static void
 g_mime_filter_md5_finalize (GObject *object)
 {
-	GMimeFilterMd5 *filter = (GMimeFilterMd5 *) object;
-	
-	g_free (filter->priv);
-	
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -120,7 +109,7 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 {
 	GMimeFilterMd5 *md5 = (GMimeFilterMd5 *) filter;
 	
-	md5_update (&md5->priv->md5, in, len);
+	md5_update (&md5->md5, in, len);
 	
 	*out = in;
 	*outlen = len;
@@ -139,7 +128,7 @@ filter_reset (GMimeFilter *filter)
 {
 	GMimeFilterMd5 *md5 = (GMimeFilterMd5 *) filter;
 	
-	md5_init (&md5->priv->md5);
+	md5_init (&md5->md5);
 }
 
 
@@ -153,7 +142,7 @@ filter_reset (GMimeFilter *filter)
 GMimeFilter *
 g_mime_filter_md5_new (void)
 {
-	return (GMimeFilter *) g_object_new (GMIME_TYPE_FILTER_MD5, NULL);
+	return (GMimeFilter *) g_object_new (GMIME_TYPE_FILTER_MD5, NULL, NULL);
 }
 
 
@@ -169,5 +158,5 @@ g_mime_filter_md5_get_digest (GMimeFilterMd5 *md5, unsigned char digest[16])
 {
 	g_return_if_fail (GMIME_IS_FILTER_MD5 (md5));
 	
-	md5_final (&md5->priv->md5, digest);
+	md5_final (&md5->md5, digest);
 }
