@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -612,6 +612,7 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 	char *status_fd = NULL, *passwd_fd = NULL;
 	int i, maxfd, errnosave, fds[10];
 	GPtrArray *argv;
+	int flags;
 	
 	for (i = 0; i < 10; i++)
 		fds[i] = -1;
@@ -639,16 +640,11 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 		setsid ();
 		
 		maxfd = sysconf (_SC_OPEN_MAX);
-		if (maxfd > 0) {
-			/* Loop over all fds. */
-			for (i = 0; i < maxfd; i++) {
-				if ((i != STDIN_FILENO) &&
-				    (i != STDOUT_FILENO) &&
-				    (i != STDERR_FILENO) &&
-				    (i != fds[7]) &&  /* status fd */
-				    (i != fds[8]))    /* passwd fd */
-					close (i);
-			}
+		/* Loop over all fds. */
+		for (i = 3; i < maxfd; i++) {
+			/* don't close status-fd or passwd-fd */
+			if (i != fds[7] && i != fds[8])
+				fcntl (i, F_SETFD, FD_CLOEXEC);
 		}
 		
 		/* run gpg */
@@ -677,13 +673,21 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 	if (gpg->need_passwd) {
 		close (fds[8]);
 		gpg->passwd_fd = fds[9];
-		fcntl (gpg->passwd_fd, F_SETFL, O_NONBLOCK);
+		flags = (flags = fcntl (gpg->passwd_fd, F_GETFL)) == -1 ? O_WRONLY : flags;
+		fcntl (gpg->passwd_fd, F_SETFL, flags | O_NONBLOCK);
 	}
 	
-	fcntl (gpg->stdin_fd, F_SETFL, O_NONBLOCK);
-	fcntl (gpg->stdout_fd, F_SETFL, O_NONBLOCK);
-	fcntl (gpg->stderr_fd, F_SETFL, O_NONBLOCK);
-	fcntl (gpg->status_fd, F_SETFL, O_NONBLOCK);
+	flags = (flags = fcntl (gpg->stdin_fd, F_GETFL)) == -1 ? O_WRONLY : flags;
+	fcntl (gpg->stdin_fd, F_SETFL, flags | O_NONBLOCK);
+	
+	flags = (flags = fcntl (gpg->stdout_fd, F_GETFL)) == -1 ? O_RDONLY : flags;
+	fcntl (gpg->stdout_fd, F_SETFL, flags | O_NONBLOCK);
+	
+	flags = (flags = fcntl (gpg->stderr_fd, F_GETFL)) == -1 ? O_RDONLY : flags;
+	fcntl (gpg->stderr_fd, F_SETFL, flags | O_NONBLOCK);
+	
+	flags = (flags = fcntl (gpg->status_fd, F_GETFL)) == -1 ? O_RDONLY : flags;
+	fcntl (gpg->status_fd, F_SETFL, flags | O_NONBLOCK);
 	
 	return 0;
 	
