@@ -24,6 +24,11 @@
 #ifndef __GMIME_MESSAGE_H__
 #define __GMIME_MESSAGE_H__
 
+#ifdef __cplusplus
+extern "C" {
+#pragma }
+#endif /* __cplusplus */
+
 #include <stdarg.h>
 #include <time.h>
 
@@ -32,11 +37,6 @@
 #include <gmime/gmime-stream.h>
 #include <gmime/internet-address.h>
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
-
 #define GMIME_TYPE_MESSAGE            (g_mime_message_get_type ())
 #define GMIME_MESSAGE(obj)            (GMIME_CHECK_CAST ((obj), GMIME_TYPE_MESSAGE, GMimeMessage))
 #define GMIME_MESSAGE_CLASS(klass)    (GMIME_CHECK_CLASS_CAST ((klass), GMIME_TYPE_MESSAGE, GMimeMessageClass))
@@ -126,10 +126,9 @@ const char *g_mime_message_get_header (GMimeMessage *message, const char *header
 
 void g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part);
 
-#ifndef GMIME_DISABLE_DEPRECATED
+/* utility functions */
 ssize_t g_mime_message_write_to_stream (GMimeMessage *message, GMimeStream *stream);
 char *g_mime_message_to_string (GMimeMessage *message);
-#endif /* GMIME_DISABLE_DEPRECATED */
 
 char *g_mime_message_get_body (const GMimeMessage *message, gboolean want_plain, gboolean *is_html);
 char *g_mime_message_get_headers (GMimeMessage *message);
