@@ -144,7 +144,7 @@ g_mime_multipart_finalize (GObject *object)
 		GMimeObject *part;
 		
 		part = node->data;
-		g_object_unref (part);
+		g_mime_object_unref (part);
 		node = node->next;
 	}
 	g_list_free (multipart->subparts);
@@ -166,7 +166,7 @@ multipart_add_header (GMimeObject *object, const char *header, const char *value
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a multipart */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		GMIME_OBJECT_CLASS (parent_class)->add_header (object, header, value);
 }
 
@@ -174,13 +174,13 @@ static void
 multipart_set_header (GMimeObject *object, const char *header, const char *value)
 {
 	/* RFC 1864 states that you cannot set a Content-MD5 on a multipart */
-	if (!strcasecmp ("Content-MD5", header))
+	if (!g_strcasecmp ("Content-MD5", header))
 		return;
 	
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a multipart */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		GMIME_OBJECT_CLASS (parent_class)->set_header (object, header, value);
 }
 
@@ -190,7 +190,7 @@ multipart_get_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a multipart */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 	else
 		return NULL;
@@ -202,7 +202,7 @@ multipart_remove_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a multipart */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
@@ -238,7 +238,8 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		g_mime_multipart_set_boundary (multipart, NULL);
 	
 	/* write the content headers */
-	if ((nwritten = g_mime_header_write_to_stream (object->headers, stream)) == -1)
+	nwritten = g_mime_header_write_to_stream (object->headers, stream);
+	if (nwritten == -1)
 		return -1;
 	
 	total += nwritten;
@@ -251,7 +252,8 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		
 		total++;
 		
-		if ((nwritten = g_mime_stream_write_string (stream, multipart->preface)) == -1)
+		nwritten = g_mime_stream_write_string (stream, multipart->preface);
+		if (nwritten == -1)
 			return -1;
 		
 		total += nwritten;
@@ -262,13 +264,15 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		part = node->data;
 		
 		/* write the boundary */
-		if ((nwritten = g_mime_stream_printf (stream, "\n--%s\n", multipart->boundary)) == -1)
+		nwritten = g_mime_stream_printf (stream, "\n--%s\n", multipart->boundary);
+		if (nwritten == -1)
 			return -1;
 		
 		total += nwritten;
 		
 		/* write this part out */
-		if ((nwritten = g_mime_object_write_to_stream (part, stream)) == -1)
+		nwritten = g_mime_object_write_to_stream (part, stream);
+		if (nwritten == -1)
 			return -1;
 		
 		total += nwritten;
@@ -276,14 +280,16 @@ multipart_write_to_stream (GMimeObject *object, GMimeStream *stream)
 		node = node->next;
 	}
 	
-	if ((nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary)) == -1)
+	nwritten = g_mime_stream_printf (stream, "\n--%s--\n", multipart->boundary);
+	if (nwritten == -1)
 		return -1;
 	
 	total += nwritten;
 	
 	/* write the postface */
 	if (multipart->postface) {
-		if ((nwritten = g_mime_stream_write_string (stream, multipart->postface)) == -1)
+		nwritten = g_mime_stream_write_string (stream, multipart->postface);
+		if (nwritten == -1)
 			return -1;
 		
 		total += nwritten;
@@ -413,7 +419,7 @@ g_mime_multipart_get_postface (GMimeMultipart *multipart)
 static void
 multipart_add_part (GMimeMultipart *multipart, GMimeObject *part)
 {
-	g_object_ref (part);
+	g_mime_object_ref (part);
 	multipart->subparts = g_list_append (multipart->subparts, part);
 }
 
@@ -438,7 +444,7 @@ g_mime_multipart_add_part (GMimeMultipart *multipart, GMimeObject *part)
 static void
 multipart_add_part_at (GMimeMultipart *multipart, GMimeObject *part, int index)
 {
-	g_object_ref (part);
+	g_mime_object_ref (part);
 	multipart->subparts = g_list_insert (multipart->subparts, part, index);
 }
 
@@ -494,7 +500,7 @@ multipart_remove_part (GMimeMultipart *multipart, GMimeObject *part)
 	
 	g_list_free_1 (node);
 	
-	g_object_unref (part);
+	g_mime_object_unref (part);
 }
 
 
@@ -576,7 +582,7 @@ multipart_get_part (GMimeMultipart *multipart, int index)
 	
 	part = node->data;
 	
-	g_object_ref (part);
+	g_mime_object_ref (part);
 	
 	return part;
 }
@@ -633,8 +639,10 @@ read_random_pool (char *buffer, size_t bytes)
 {
 	int fd;
 	
-	if ((fd = open ("/dev/urandom", O_RDONLY)) == -1) {
-		if ((fd = open ("/dev/random", O_RDONLY)) == -1)
+	fd = open ("/dev/urandom", O_RDONLY);
+	if (fd == -1) {
+		fd = open ("/dev/random", O_RDONLY);
+		if (fd == -1)
 			return;
 	}
 	
@@ -722,7 +730,7 @@ g_mime_multipart_get_boundary (GMimeMultipart *multipart)
  * @callback: function to call for @multipart and all of its subparts
  * @user_data: extra data to pass to the callback
  * 
- * Calls @callback on each of @multipart's subparts.
+ * Calls @callback on @multipart and each of its subparts.
  **/
 void
 g_mime_multipart_foreach (GMimeMultipart *multipart, GMimePartFunc callback, gpointer user_data)
@@ -754,7 +762,7 @@ g_mime_multipart_foreach (GMimeMultipart *multipart, GMimePartFunc callback, gpo
  * Returns the GMimeObject whose content-id matches the search string,
  * or %NULL if a match cannot be found.
  **/
-GMimeObject *
+const GMimeObject *
 g_mime_multipart_get_subpart_from_content_id (GMimeMultipart *multipart, const char *content_id)
 {
 	GMimeObject *object = (GMimeObject *) multipart;
@@ -763,22 +771,20 @@ g_mime_multipart_get_subpart_from_content_id (GMimeMultipart *multipart, const c
 	g_return_val_if_fail (GMIME_IS_MULTIPART (multipart), NULL);
 	g_return_val_if_fail (content_id != NULL, NULL);
 	
-	if (object->content_id && !strcmp (object->content_id, content_id)) {
-		g_object_ref (object);
+	if (object->content_id && !strcmp (object->content_id, content_id))
 		return object;
-	}
 	
 	subparts = multipart->subparts;
 	while (subparts) {
-		GMimeObject *part = NULL;
+		const GMimeObject *part = NULL;
 		GMimeObject *subpart;
 		
 		subpart = subparts->data;
 		
 		if (GMIME_IS_MULTIPART (subpart)) {
-			part = g_mime_multipart_get_subpart_from_content_id (GMIME_MULTIPART (subpart), content_id);
+			part = g_mime_multipart_get_subpart_from_content_id (GMIME_MULTIPART (subpart),
+									     content_id);
 		} else if (subpart->content_id && !strcmp (subpart->content_id, content_id)) {
-			g_object_ref (subpart);
 			part = subpart;
 		}
 		
