@@ -1,8 +1,8 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@helixcode.com>
+ *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2000 Helix Code, Inc. (www.helixcode.com)
+ *  Copyright 2000-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,8 +36,14 @@
 #include "gmime-iconv.h"
 #include "gmime-iconv-utils.h"
 
-#define d(x) x
+
+#ifdef ENABLE_WARNINGS
+#define w(x) x
+#else
 #define w(x)
+#endif /* ENABLE_WARNINGS */
+
+#define d(x)
 
 
 static unsigned char tohex[16] = {
@@ -657,7 +663,7 @@ encode_param (const unsigned char *in, gboolean *encoded)
 	
 	/* FIXME: set the 'language' as well, assuming we can get that info...? */
 	out = g_string_new ("");
-	g_string_sprintfa (out, "%s''", charset);
+	g_string_append_printf (out, "%s''", charset);
 	
 	while (inptr && *inptr) {
 		unsigned char c = *inptr++;
@@ -665,9 +671,9 @@ encode_param (const unsigned char *in, gboolean *encoded)
 		/* FIXME: make sure that '\'', '*', and ';' are also encoded */
 		
 		if (c > 127) {
-			g_string_sprintfa (out, "%%%c%c", tohex[(c >> 4) & 0xf], tohex[c & 0xf]);
+			g_string_append_printf (out, "%%%c%c", tohex[(c >> 4) & 0xf], tohex[c & 0xf]);
 		} else if (is_lwsp (c) || !(gmime_special_table[c] & IS_ESAFE)) {
-			g_string_sprintfa (out, "%%%c%c", tohex[(c >> 4) & 0xf], tohex[c & 0xf]);
+			g_string_append_printf (out, "%%%c%c", tohex[(c >> 4) & 0xf], tohex[c & 0xf]);
 		} else {
 			g_string_append_c (out, c);
 		}
@@ -786,7 +792,8 @@ param_list_format (GString *out, GMimeParam *param, gboolean fold)
 					used = 0;
 				}
 				
-				g_string_sprintfa (out, "%s*%d%s=", param->name, i++, encoded ? "*" : "");
+				g_string_append_printf (out, "%s*%d%s=", param->name,
+							i++, encoded ? "*" : "");
 				
 				if (encoded || !quote)
 					g_string_append_len (out, inptr, ptr - inptr);
@@ -798,7 +805,7 @@ param_list_format (GString *out, GMimeParam *param, gboolean fold)
 				inptr = ptr;
 			}
 		} else {
-			g_string_sprintfa (out, "%s%s=", param->name, encoded ? "*" : "");
+			g_string_append_printf (out, "%s%s=", param->name, encoded ? "*" : "");
 			
 			if (encoded || !quote)
 				g_string_append_len (out, value, vlen);
