@@ -42,8 +42,6 @@
 #include "gmime-filter-crlf.h"
 #include "gmime-filter-md5.h"
 
-#define d(x)
-
 /* GObject class methods */
 static void g_mime_part_class_init (GMimePartClass *klass);
 static void g_mime_part_init (GMimePart *mime_part, GMimePartClass *klass);
@@ -174,18 +172,6 @@ set_disposition (GMimePart *mime_part, const char *disposition)
 	mime_part->disposition = g_mime_disposition_new (disposition);
 }
 
-static void
-sync_content_disposition (GMimePart *mime_part)
-{
-	char *str;
-	
-	if (mime_part->disposition) {
-		str = g_mime_disposition_header (mime_part->disposition, FALSE);
-		g_mime_header_set (GMIME_OBJECT (mime_part)->headers, "Content-Disposition", str);
-		g_free (str);
-	}
-}
-
 static gboolean
 process_header (GMimeObject *object, const char *header, const char *value)
 {
@@ -194,7 +180,7 @@ process_header (GMimeObject *object, const char *header, const char *value)
 	int i;
 	
 	for (i = 0; headers[i]; i++) {
-		if (!strcasecmp (headers[i], header))
+		if (!g_strcasecmp (headers[i], header))
 			break;
 	}
 	
@@ -235,7 +221,7 @@ mime_part_add_header (GMimeObject *object, const char *header, const char *value
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8)) {
+	if (!g_strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_add (object->headers, header, value);
 		else
@@ -249,7 +235,7 @@ mime_part_set_header (GMimeObject *object, const char *header, const char *value
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8)) {
+	if (!g_strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_set (object->headers, header, value);
 		else
@@ -263,7 +249,7 @@ mime_part_get_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
            doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 	else
 		return NULL;
@@ -275,7 +261,7 @@ mime_part_remove_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is a Content-* header, else it
 	   doesn't belong on a mime part */
 	
-	if (!strncasecmp ("Content-", header, 8))
+	if (!g_strncasecmp ("Content-", header, 8))
 		GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
@@ -321,7 +307,7 @@ write_content (GMimePart *part, GMimeStream *stream)
 			nwritten = g_mime_stream_printf (stream, "begin 0644 %s\n",
 							 filename ? filename : "unknown");
 			if (nwritten == -1) {
-				g_object_unref (filtered_stream);
+				g_mime_stream_unref (filtered_stream);
 				return -1;
 			}
 			
@@ -337,7 +323,7 @@ write_content (GMimePart *part, GMimeStream *stream)
 		
 		nwritten = g_mime_data_wrapper_write_to_stream (part->content, filtered_stream);
 		g_mime_stream_flush (filtered_stream);
-		g_object_unref (filtered_stream);
+		g_mime_stream_unref (filtered_stream);
 		
 		if (nwritten == -1)
 			return -1;
@@ -358,7 +344,7 @@ write_content (GMimePart *part, GMimeStream *stream)
 		content_stream = g_mime_data_wrapper_get_stream (part->content);
 		g_mime_stream_reset (content_stream);
 		nwritten = g_mime_stream_write_to_stream (content_stream, stream);
-		g_object_unref (content_stream);
+		g_mime_stream_unref (content_stream);
 		
 		if (nwritten == -1)
 			return -1;
@@ -376,7 +362,8 @@ mime_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	ssize_t nwritten, total = 0;
 	
 	/* write the content headers */
-	if ((nwritten = g_mime_header_write_to_stream (object->headers, stream)) == -1)
+	nwritten = g_mime_header_write_to_stream (object->headers, stream);
+	if (nwritten == -1)
 		return -1;
 	
 	total += nwritten;
@@ -387,7 +374,8 @@ mime_part_write_to_stream (GMimeObject *object, GMimeStream *stream)
 	
 	total++;
 	
-	if ((nwritten = write_content (mime_part, stream)) == -1)
+	nwritten = write_content (mime_part, stream);
+	if (nwritten == -1)
 		return -1;
 	
 	total += nwritten;
@@ -581,7 +569,7 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
 		/* compute a md5sum */
 		stream = g_mime_stream_null_new ();
 		filtered_stream = (GMimeStreamFilter *) g_mime_stream_filter_new_with_stream (stream);
-		g_object_unref (stream);
+		g_mime_stream_unref (stream);
 		
 		content_type = g_mime_object_get_content_type ((GMimeObject *) mime_part);
 		if (g_mime_content_type_is_type (content_type, "text", "*")) {
@@ -599,7 +587,7 @@ g_mime_part_set_content_md5 (GMimePart *mime_part, const char *content_md5)
 		
 		stream = (GMimeStream *) filtered_stream;
 		g_mime_data_wrapper_write_to_stream (mime_part->content, stream);
-		g_object_unref (stream);
+		g_mime_stream_unref (stream);
 		
 		memset (digest, 0, 16);
 		g_mime_filter_md5_get_digest ((GMimeFilterMd5 *) md5_filter, digest);
@@ -646,7 +634,7 @@ g_mime_part_verify_content_md5 (GMimePart *mime_part)
 	
 	stream = g_mime_stream_null_new ();
 	filtered_stream = (GMimeStreamFilter *) g_mime_stream_filter_new_with_stream (stream);
-	g_object_unref (stream);
+	g_mime_stream_unref (stream);
 	
 	content_type = g_mime_object_get_content_type ((GMimeObject *) mime_part);
 	if (g_mime_content_type_is_type (content_type, "text", "*")) {
@@ -664,7 +652,7 @@ g_mime_part_verify_content_md5 (GMimePart *mime_part)
 	
 	stream = (GMimeStream *) filtered_stream;
 	g_mime_data_wrapper_write_to_stream (mime_part->content, stream);
-	g_object_unref (stream);
+	g_mime_stream_unref (stream);
 	
 	memset (digest, 0, 16);
 	g_mime_filter_md5_get_digest ((GMimeFilterMd5 *) md5_filter, digest);
@@ -867,22 +855,33 @@ g_mime_part_encoding_to_string (GMimePartEncodingType encoding)
 GMimePartEncodingType
 g_mime_part_encoding_from_string (const char *encoding)
 {
-	if (!strcasecmp (encoding, "7bit"))
+	if (!g_strcasecmp (encoding, "7bit"))
 		return GMIME_PART_ENCODING_7BIT;
-	else if (!strcasecmp (encoding, "8bit"))
+	else if (!g_strcasecmp (encoding, "8bit"))
 		return GMIME_PART_ENCODING_8BIT;
-	else if (!strcasecmp (encoding, "binary"))
+	else if (!g_strcasecmp (encoding, "binary"))
 		return GMIME_PART_ENCODING_BINARY;
-	else if (!strcasecmp (encoding, "base64"))
+	else if (!g_strcasecmp (encoding, "base64"))
 		return GMIME_PART_ENCODING_BASE64;
-	else if (!strcasecmp (encoding, "quoted-printable"))
+	else if (!g_strcasecmp (encoding, "quoted-printable"))
 		return GMIME_PART_ENCODING_QUOTEDPRINTABLE;
-	else if (!strcasecmp (encoding, "x-uuencode"))
+	else if (!g_strcasecmp (encoding, "x-uuencode"))
 		return GMIME_PART_ENCODING_UUENCODE;
 	else return GMIME_PART_ENCODING_DEFAULT;
 }
 
 
+static void
+sync_content_disposition (GMimePart *mime_part)
+{
+	char *str;
+	
+	str = g_mime_disposition_header (mime_part->disposition, FALSE);
+	g_mime_header_set (GMIME_OBJECT (mime_part)->headers, "Content-Disposition", str);
+	g_free (str);
+}
+
+
 /**
  * g_mime_part_set_content_disposition_object:
  * @mime_part: Mime part
@@ -1048,9 +1047,6 @@ g_mime_part_get_filename (const GMimePart *mime_part)
  * @content: raw mime part content
  * @len: raw content length
  *
- * WARNING: This interface is deprecated. Use
- * g_mime_part_set_content_object() instead.
- *
  * Sets the content of the Mime Part (only non-multiparts)
  **/
 void
@@ -1066,7 +1062,7 @@ g_mime_part_set_content (GMimePart *mime_part, const char *content, size_t len)
 	stream = g_mime_stream_mem_new_with_buffer (content, len);
 	g_mime_data_wrapper_set_stream (mime_part->content, stream);
 	g_mime_data_wrapper_set_encoding (mime_part->content, GMIME_PART_ENCODING_DEFAULT);
-	g_object_unref (stream);
+	g_mime_stream_unref (stream);
 }
 
 
@@ -1075,9 +1071,6 @@ g_mime_part_set_content (GMimePart *mime_part, const char *content, size_t len)
  * @mime_part: Mime part
  * @content: raw mime part content.
  *
- * WARNING: This interface is deprecated. Use
- * g_mime_part_set_content_object() instead.
- *
  * Sets the content of the Mime Part (only non-multiparts)
  **/
 void
@@ -1093,7 +1086,7 @@ g_mime_part_set_content_byte_array (GMimePart *mime_part, GByteArray *content)
 	stream = g_mime_stream_mem_new_with_byte_array (content);
 	g_mime_data_wrapper_set_stream (mime_part->content, stream);
 	g_mime_data_wrapper_set_encoding (mime_part->content, GMIME_PART_ENCODING_DEFAULT);
-	g_object_unref (stream);
+	g_mime_stream_unref (stream);
 }
 
 
@@ -1104,11 +1097,7 @@ g_mime_part_set_content_byte_array (GMimePart *mime_part, GByteArray *content)
  * @len: length of the content
  * @encoding: content encoding
  *
- * WARNING: This interface is deprecated. Use
- * g_mime_part_set_content_object() instead.
- *
- * Sets the encoding type and raw content on the mime part after
- * decoding the content.
+ * Sets the encoding type and raw content on the mime part after decoding the content.
  **/
 void
 g_mime_part_set_pre_encoded_content (GMimePart *mime_part, const char *content,
@@ -1147,12 +1136,12 @@ g_mime_part_set_pre_encoded_content (GMimePart *mime_part, const char *content,
 	
 	g_mime_stream_write (filtered_stream, (char *) content, len);
 	g_mime_stream_flush (filtered_stream);
-	g_object_unref (filtered_stream);
+	g_mime_stream_unref (filtered_stream);
 	
 	g_mime_stream_reset (stream);
 	g_mime_data_wrapper_set_stream (mime_part->content, stream);
 	g_mime_data_wrapper_set_encoding (mime_part->content, GMIME_PART_ENCODING_DEFAULT);
-	g_object_unref (stream);
+	g_mime_stream_unref (stream);
 	
 	mime_part->encoding = encoding;
 }
@@ -1208,16 +1197,10 @@ g_mime_part_get_content_object (const GMimePart *mime_part)
  *
  * Gets the raw contents of the mime part and sets @len to the length
  * of the raw data buffer.
- *
- * WARNING: This interface is deprecated. Use
- * g_mime_get_content_object() instead.
  * 
  * Returns a const char * pointer to the raw contents of the MIME Part
- * and sets @len to the length of the buffer. Note: textual content
- * will not be converted to UTF-8. Also note that this buffer will not
- * be nul-terminated and may in fact contain nul bytes mid-buffer so
- * you MUST treat the data returned as raw binary data even if the
- * content type is text.
+ * and sets %len to the length of the buffer. Note: textual content
+ * will not be converted to UTF-8.
  **/
 const char *
 g_mime_part_get_content (const GMimePart *mime_part, size_t *len)
@@ -1228,7 +1211,7 @@ g_mime_part_get_content (const GMimePart *mime_part, size_t *len)
 	g_return_val_if_fail (GMIME_IS_PART (mime_part), NULL);
 	
 	if (!mime_part->content || !mime_part->content->stream) {
-		d(g_warning ("no content set on this mime part"));
+		g_warning ("no content set on this mime part");
 		return NULL;
 	}
 	
@@ -1245,7 +1228,7 @@ g_mime_part_get_content (const GMimePart *mime_part, size_t *len)
 		
 		g_mime_data_wrapper_set_stream (mime_part->content, cache);
 		g_mime_data_wrapper_set_encoding (mime_part->content, GMIME_PART_ENCODING_DEFAULT);
-		g_object_unref (cache);
+		g_mime_stream_unref (cache);
 		
 		*len = buf->len;
 		retval = buf->data;
@@ -1277,9 +1260,6 @@ g_mime_part_get_content (const GMimePart *mime_part, size_t *len)
  *
  * Writes the contents of the MIME Part to @stream.
  *
- * WARNING: This interface is deprecated. Use
- * g_mime_object_write_to_stream() instead.
- *
  * Returns the number of bytes written or -1 on fail.
  **/
 ssize_t
@@ -1288,7 +1268,7 @@ g_mime_part_write_to_stream (GMimePart *mime_part, GMimeStream *stream)
 	g_return_val_if_fail (GMIME_IS_PART (mime_part), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (stream), -1);
 	
-	return g_mime_object_write_to_stream ((GMimeObject *) mime_part, stream);
+	return g_mime_object_write_to_stream (GMIME_OBJECT (mime_part), stream);
 }
 
 
@@ -1298,9 +1278,6 @@ g_mime_part_write_to_stream (GMimePart *mime_part, GMimeStream *stream)
  *
  * Allocates a string buffer containing the MIME Part.
  *
- * WARNING: This interface is deprecated. Use
- * g_mime_object_to_string() instead.
- *
  * Returns an allocated string containing the MIME Part.
  **/
 char *
@@ -1308,5 +1285,5 @@ g_mime_part_to_string (GMimePart *mime_part)
 {
 	g_return_val_if_fail (GMIME_IS_PART (mime_part), NULL);
 	
-	return g_mime_object_to_string ((GMimeObject *) mime_part);
+	return g_mime_object_to_string (GMIME_OBJECT (mime_part));
 }
