@@ -24,13 +24,13 @@
 #ifndef __GMIME_STREAM_BUFFER_H__
 #define __GMIME_STREAM_BUFFER_H__
 
-#include <gmime/gmime-stream.h>
-
 #ifdef __cplusplus
 extern "C" {
 #pragma }
 #endif /* __cplusplus */
 
+#include <gmime/gmime-stream.h>
+
 #define GMIME_TYPE_STREAM_BUFFER            (g_mime_stream_buffer_get_type ())
 #define GMIME_STREAM_BUFFER(obj)            (GMIME_CHECK_CAST ((obj), GMIME_TYPE_STREAM_BUFFER, GMimeStreamBuffer))
 #define GMIME_STREAM_BUFFER_CLASS(klass)    (GMIME_CHECK_CLASS_CAST ((klass), GMIME_TYPE_STREAM_BUFFER, GMimeStreamBufferClass))
@@ -42,7 +42,7 @@ extern "C" {
 typedef enum {
 	GMIME_STREAM_BUFFER_CACHE_READ,
 	GMIME_STREAM_BUFFER_BLOCK_READ,
-	GMIME_STREAM_BUFFER_BLOCK_WRITE
+	GMIME_STREAM_BUFFER_BLOCK_WRITE,
 } GMimeStreamBufferMode;
 
 typedef struct _GMimeStreamBuffer GMimeStreamBuffer;
