@@ -32,7 +32,7 @@ static void g_mime_stream_cat_init (GMimeStreamCat *stream, GMimeStreamCatClass
 static void g_mime_stream_cat_finalize (GObject *object);
 
 static ssize_t stream_read (GMimeStream *stream, char *buf, size_t len);
-static ssize_t stream_write (GMimeStream *stream, const char *buf, size_t len);
+static ssize_t stream_write (GMimeStream *stream, char *buf, size_t len);
 static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
@@ -115,7 +115,7 @@ g_mime_stream_cat_finalize (GObject *object)
 	p = cat->sources;
 	while (p) {
 		n = p->next;
-		g_object_unref (p->stream);
+		g_mime_stream_unref (p->stream);
 		g_free (p);
 		p = n;
 	}
@@ -175,7 +175,7 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 }
  
 static ssize_t
-stream_write (GMimeStream *stream, const char *buf, size_t len)
+stream_write (GMimeStream *stream, char *buf, size_t len)
 {
 	GMimeStreamCat *cat = (GMimeStreamCat *) stream;
 	struct _cat_node *current;
@@ -199,7 +199,7 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 	do {
 		n = -1;
 		while (!g_mime_stream_eos (current->stream) && nwritten < len) {
-			n = g_mime_stream_write (current->stream, buf + nwritten, len - nwritten);
+			n = g_mime_stream_read (current->stream, buf + nwritten, len - nwritten);
 			if (n > 0)
 				nwritten += n;
 		}
@@ -457,7 +457,7 @@ g_mime_stream_cat_add_source (GMimeStreamCat *cat, GMimeStream *source)
 	node->next = NULL;
 	node->stream = source;
 	node->length = len;
-	g_object_ref (source);
+	g_mime_stream_ref (source);
 	
 	p = cat->sources;
 	while (p && p->next)
