@@ -58,8 +58,8 @@ static void g_mime_stream_filter_class_init (GMimeStreamFilterClass *klass);
 static void g_mime_stream_filter_init (GMimeStreamFilter *stream, GMimeStreamFilterClass *klass);
 static void g_mime_stream_filter_finalize (GObject *object);
 
-static ssize_t stream_read (GMimeStream *stream, char *buf, size_t n);
-static ssize_t stream_write (GMimeStream *stream, const char *buf, size_t n);
+static ssize_t stream_read (GMimeStream *stream, char *buf, size_t len);
+static ssize_t stream_write (GMimeStream *stream, char *buf, size_t len);
 static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
@@ -153,83 +153,83 @@ g_mime_stream_filter_finalize (GObject *object)
 	g_free (p);
 	
 	if (filter->source)
-		g_object_unref (filter->source);
+		g_mime_stream_unref (filter->source);
 	
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 
 static ssize_t
-stream_read (GMimeStream *stream, char *buf, size_t n)
+stream_read (GMimeStream *stream, char *buf, size_t len)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
-	struct _GMimeStreamFilterPrivate *priv = filter->priv;
+	struct _GMimeStreamFilterPrivate *p = filter->priv;
 	struct _filter *f;
-	ssize_t nread;
+	ssize_t size;
 	
-	priv->last_was_read = TRUE;
+	p->last_was_read = TRUE;
 	
-	if (priv->filteredlen <= 0) {
+	if (p->filteredlen <= 0) {
 		size_t presize = READ_SIZE;
 		
-		nread = g_mime_stream_read (filter->source, priv->buffer, READ_SIZE);
-		if (nread <= 0) {
+		size = g_mime_stream_read (filter->source, p->buffer, READ_SIZE);
+		if (size <= 0) {
 			/* this is somewhat untested */
-			if (g_mime_stream_eos (filter->source) && !priv->flushed) {
-				priv->filtered = priv->buffer;
-				priv->filteredlen = 0;
-				f = priv->filters;
-				
-				while (f != NULL) {
-					g_mime_filter_complete (f->filter, priv->filtered, priv->filteredlen,
-								presize, &priv->filtered, &priv->filteredlen,
+			if (g_mime_stream_eos (filter->source)) {
+				f = p->filters;
+				p->filtered = p->buffer;
+				p->filteredlen = 0;
+				while (f) {
+					g_mime_filter_complete (f->filter, p->filtered, p->filteredlen,
+								presize, &p->filtered, &p->filteredlen,
 								&presize);
 					f = f->next;
 				}
-				
-				nread = priv->filteredlen;
-				priv->flushed = TRUE;
+				size = p->filteredlen;
+				p->flushed = TRUE;
 			}
-			
-			if (nread <= 0)
-				return nread;
+			if (size <= 0)
+				return size;
 		} else {
-			priv->filtered = priv->buffer;
-			priv->filteredlen = nread;
-			f = priv->filters;
+			f = p->filters;
+			p->filtered = p->buffer;
+			p->filteredlen = size;
 			
-			while (f != NULL) {
-				g_mime_filter_filter (f->filter, priv->filtered, priv->filteredlen, presize,
-						      &priv->filtered, &priv->filteredlen, &presize);
+			while (f) {
+				g_mime_filter_filter (f->filter, p->filtered, p->filteredlen, presize,
+						      &p->filtered, &p->filteredlen, &presize);
 				
 				f = f->next;
 			}
 		}
 	}
 	
-	nread = MIN (n, priv->filteredlen);
-	memcpy (buf, priv->filtered, nread);
-	priv->filteredlen -= nread;
-	priv->filtered += nread;
+	size = MIN (len, p->filteredlen);
+	memcpy (buf, p->filtered, size);
+	p->filteredlen -= size;
+	p->filtered += size;
 	
-	return nread;
+	return size;
 }
 
 static ssize_t
-stream_write (GMimeStream *stream, const char *buf, size_t n)
+stream_write (GMimeStream *stream, char *buf, size_t len)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
-	struct _GMimeStreamFilterPrivate *priv = filter->priv;
-	char *buffer = (char *) buf;
-	ssize_t nwritten = n;
+	struct _GMimeStreamFilterPrivate *p = filter->priv;
 	struct _filter *f;
 	size_t presize;
+	char *buffer;
+	size_t n;
 	
-	priv->last_was_read = FALSE;
+	p->last_was_read = FALSE;
 	
-	f = priv->filters;
+	buffer = buf;
+	n = len;
+	
+	f = p->filters;
 	presize = 0;
-	while (f != NULL) {
+	while (f) {
 		g_mime_filter_filter (f->filter, buffer, n, presize, &buffer, &n, &presize);
 		
 		f = f->next;
@@ -238,20 +238,20 @@ stream_write (GMimeStream *stream, const char *buf, size_t n)
 	if (g_mime_stream_write (filter->source, buffer, n) != n)
 		return -1;
 	
-	/* return original input len because that's what our caller expects */
-	return nwritten;
+	/* return 'len' because that's what our caller expects */
+	return len;
 }
 
 static int
 stream_flush (GMimeStream *stream)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
-	struct _GMimeStreamFilterPrivate *priv = filter->priv;
+	struct _GMimeStreamFilterPrivate *p = filter->priv;
 	size_t presize, len;
 	struct _filter *f;
 	char *buffer;
 	
-	if (priv->last_was_read) {
+	if (p->last_was_read) {
 		/* no-op */
 		return 0;
 	}
@@ -259,9 +259,9 @@ stream_flush (GMimeStream *stream)
 	buffer = "";
 	len = 0;
 	presize = 0;
-	f = priv->filters;
+	f = p->filters;
 	
-	while (f != NULL) {
+	while (f) {
 		g_mime_filter_complete (f->filter, buffer, len, presize, &buffer, &len, &presize);
 		
 		f = f->next;
@@ -277,10 +277,11 @@ static int
 stream_close (GMimeStream *stream)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
-	struct _GMimeStreamFilterPrivate *priv = filter->priv;
+	struct _GMimeStreamFilterPrivate *p = filter->priv;
 	
-	if (!priv->last_was_read)
+	if (!p->last_was_read) {
 		stream_flush (stream);
+	}
 	
 	return g_mime_stream_close (filter->source);
 }
@@ -289,12 +290,12 @@ static gboolean
 stream_eos (GMimeStream *stream)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
-	struct _GMimeStreamFilterPrivate *priv = filter->priv;
+	struct _GMimeStreamFilterPrivate *p = filter->priv;
 	
-	if (priv->filteredlen > 0)
+	if (p->filteredlen > 0)
 		return FALSE;
 	
-	if (!priv->flushed)
+	if (!p->flushed)
 		return FALSE;
 	
 	return g_mime_stream_eos (filter->source);
@@ -304,15 +305,15 @@ static int
 stream_reset (GMimeStream *stream)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
-	struct _GMimeStreamFilterPrivate *priv = filter->priv;
+	struct _GMimeStreamFilterPrivate *p = filter->priv;
 	struct _filter *f;
 	
-	priv->filteredlen = 0;
-	priv->flushed = FALSE;
+	p->filteredlen = 0;
+	p->flushed = FALSE;
 	
 	/* and reset filters */
-	f = priv->filters;
-	while (f != NULL) {
+	f = p->filters;
+	while (f) {
 		g_mime_filter_reset (f->filter);
 		f = f->next;
 	}
@@ -323,6 +324,8 @@ stream_reset (GMimeStream *stream)
 static off_t
 stream_seek (GMimeStream *stream, off_t offset, GMimeSeekWhence whence)
 {
+	/*GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;*/
+	
 	return -1;
 }
 
@@ -343,10 +346,11 @@ stream_substream (GMimeStream *stream, off_t start, off_t end)
 {
 	GMimeStreamFilter *filter = (GMimeStreamFilter *) stream;
 	GMimeStreamFilter *sub;
+	/*struct _filter *f, *fn;*/
 	
 	sub = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL, NULL);
 	sub->source = filter->source;
-	g_object_ref (sub->source);
+	g_mime_stream_ref (sub->source);
 	
 	if (filter->priv->filters) {
 		struct _filter *f, *sn, *s = NULL;
@@ -398,7 +402,7 @@ g_mime_stream_filter_new_with_stream (GMimeStream *stream)
 	
 	filter = g_object_new (GMIME_TYPE_STREAM_FILTER, NULL, NULL);
 	filter->source = stream;
-	g_object_ref (stream);
+	g_mime_stream_ref (stream);
 	
 	g_mime_stream_construct (GMIME_STREAM (filter),
 				 stream->bound_start,
@@ -420,7 +424,7 @@ g_mime_stream_filter_new_with_stream (GMimeStream *stream)
 int
 g_mime_stream_filter_add (GMimeStreamFilter *fstream, GMimeFilter *filter)
 {
-	struct _GMimeStreamFilterPrivate *priv;
+	struct _GMimeStreamFilterPrivate *p;
 	struct _filter *f, *fn;
 	
 	g_return_val_if_fail (GMIME_IS_STREAM_FILTER (fstream), -1);
@@ -428,14 +432,14 @@ g_mime_stream_filter_add (GMimeStreamFilter *fstream, GMimeFilter *filter)
 	
 	g_object_ref (filter);
 	
-	priv = fstream->priv;
+	p = fstream->priv;
 	
 	fn = g_new (struct _filter, 1);
 	fn->next = NULL;
 	fn->filter = filter;
-	fn->id = priv->filterid++;
+	fn->id = p->filterid++;
 	
-	f = (struct _filter *) &priv->filters;
+	f = (struct _filter *) &p->filters;
 	while (f->next)
 		f = f->next;
 	
@@ -457,17 +461,17 @@ g_mime_stream_filter_add (GMimeStreamFilter *fstream, GMimeFilter *filter)
 void
 g_mime_stream_filter_remove (GMimeStreamFilter *fstream, int id)
 {
-	struct _GMimeStreamFilterPrivate *priv;
+	struct _GMimeStreamFilterPrivate *p;
 	struct _filter *f, *fn;
 	
 	g_return_if_fail (GMIME_IS_STREAM_FILTER (fstream));
 	
-	priv = fstream->priv;
+	p = fstream->priv;
 	
 	if (id == -1)
 		return;
 	
-	f = (struct _filter *) &priv->filters;
+	f = (struct _filter *) &p->filters;
 	while (f && f->next) {
 		fn = f->next;
 		if (fn->id == id) {
