@@ -61,9 +61,6 @@ GType g_mime_stream_fs_get_type (void);
 GMimeStream *g_mime_stream_fs_new (int fd);
 GMimeStream *g_mime_stream_fs_new_with_bounds (int fd, off_t start, off_t end);
 
-gboolean g_mime_stream_fs_get_owner (GMimeStreamFs *stream);
-void g_mime_stream_fs_set_owner (GMimeStreamFs *stream, gboolean owner);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
