@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -146,9 +146,9 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 	mapptr = mstream->map + stream->position;
 	
 	if (stream->bound_end == -1)
-		nread = MIN ((mstream->map + mstream->maplen) - mapptr, len);
+		nread = MIN ((off_t) ((mstream->map + mstream->maplen) - mapptr), (off_t) len);
 	else
-		nread = MIN (stream->bound_end - stream->position, len);
+		nread = MIN (stream->bound_end - stream->position, (off_t) len);
 	
 	if (nread > 0) {
 		memcpy (buf, mapptr, nread);
@@ -173,9 +173,9 @@ stream_write (GMimeStream *stream, char *buf, size_t len)
 	mapptr = mstream->map + stream->position;
 	
 	if (stream->bound_end == -1)
-		nwritten = MIN ((mstream->map + mstream->maplen) - mapptr, len);
+		nwritten = MIN ((off_t) ((mstream->map + mstream->maplen) - mapptr), (off_t) len);
 	else
-		nwritten = MIN (stream->bound_end - stream->position, len);
+		nwritten = MIN (stream->bound_end - stream->position, (off_t) len);
 	
 	if (nwritten > 0) {
 		memcpy (mapptr, buf, nwritten);
@@ -348,7 +348,7 @@ g_mime_stream_mmap_new (int fd, int prot, int flags)
 	if (fstat (fd, &st) == -1)
 		return NULL;
 	
-	map = mmap (NULL, st.st_size + getpagesize (), prot, flags, fd, 0);
+	map = mmap (NULL, st.st_size, prot, flags, fd, 0);
 	if (map == MAP_FAILED)
 		return NULL;
 	
@@ -395,7 +395,7 @@ g_mime_stream_mmap_new_with_bounds (int fd, int prot, int flags, off_t start, of
 	} else
 		st.st_size = end /* - start */;
 	
-	map = mmap (NULL, st.st_size + getpagesize (), prot, flags, fd, 0);
+	map = mmap (NULL, st.st_size, prot, flags, fd, 0);
 	if (map == MAP_FAILED)
 		return NULL;
 	
