@@ -21,18 +21,17 @@
  *
  */
 
-
 #ifndef __GMIME_UTILS_H__
 #define __GMIME_UTILS_H__
 
-#include <glib.h>
-#include <time.h>
-#include <stdarg.h>
-
 #ifdef __cplusplus
 extern "C" {
 #pragma }
-#endif /* __cplusplus */
+#endif /* __cplusplus }*/
+
+#include <glib.h>
+#include <time.h>
+#include <stdarg.h>
 
 typedef enum {
 	GMIME_PART_ENCODING_DEFAULT,
@@ -73,8 +72,6 @@ GMimeReferences *g_mime_references_decode (const char *text);
 void g_mime_references_append (GMimeReferences **refs, const char *msgid);
 void g_mime_references_clear (GMimeReferences **refs);
 
-char  *g_mime_utils_structured_header_fold (const char *in);
-char  *g_mime_utils_unstructured_header_fold (const char *in);
 char  *g_mime_utils_header_fold (const char *in);
 char  *g_mime_utils_header_printf (const char *format, ...);
 
@@ -86,17 +83,9 @@ gboolean g_mime_utils_text_is_8bit (const unsigned char *text, size_t len);
 GMimePartEncodingType g_mime_utils_best_encoding (const unsigned char *text, size_t len);
 
 /* utilities to (de/en)code headers */
-char *g_mime_utils_header_decode_text (const unsigned char *in);
-char *g_mime_utils_header_encode_text (const unsigned char *in);
-
-char *g_mime_utils_header_decode_phrase (const unsigned char *in);
-char *g_mime_utils_header_encode_phrase (const unsigned char *in);
-
-#ifndef GMIME_DISABLE_DEPRECATED
 char *g_mime_utils_8bit_header_decode (const unsigned char *in);
 char *g_mime_utils_8bit_header_encode (const unsigned char *in);
 char *g_mime_utils_8bit_header_encode_phrase (const unsigned char *in);
-#endif
 
 /* do incremental base64 (de/en)coding */
 size_t g_mime_utils_base64_decode_step (const unsigned char *in, size_t inlen, unsigned char *out, int *state, guint32 *save);
